@@ -16,8 +16,9 @@ class ClusterRoleBinding(Resource):
         name=None,
         cluster_role=None,
         subjects=None,
+        **kwargs,
     ):
-        super().__init__(name=name)
+        super().__init__(name=name, **kwargs)
         self.cluster_role = cluster_role
         self.subjects = subjects
 
